@@ -1,11 +1,3 @@
-import math
-import time
-from threading import Thread
-
-import numpy  as np
-import pandas as pd
-
-from aperturedb import Status
 from aperturedb import ParallelLoader
 from aperturedb import CSVParser
 
@@ -136,7 +128,14 @@ class BBoxLoader(ParallelLoader.ParallelLoader):
             }
 
             if "properties" in data:
-                ai["AddBoundingBox"]["properties"] = data[CSVParser.PROPERTIES]
+                props = data[CSVParser.PROPERTIES]
+                if "_label" in props:
+                    ai["AddBoundingBox"]["label"] = props["_label"]
+                    props.pop("_label")
+
+                # Check if props is not empty after removing "_label"
+                if props:
+                    ai["AddBoundingBox"]["properties"] = props
 
             q.append(ai)
 
