@@ -1,11 +1,5 @@
-import math
-import time
-from threading import Thread
-
 import numpy as np
-import cv2
 
-from aperturedb import Status
 from aperturedb import ParallelLoader
 from aperturedb import CSVParser
 
@@ -51,7 +45,8 @@ class DescriptorGeneratorCSV(CSVParser.CSVParser):
         descriptor, desc_ok = self.load_descriptor(filename, index)
 
         if not desc_ok:
-            Exception("Error loading descriptor: " + filename + ":" + index)
+            print("Error loading descriptor: " + filename + ":" + index)
+            raise Exception("Error loading descriptor: " + filename + ":" + index)
 
         data = {
             "descriptor_blob": descriptor,
@@ -76,7 +71,13 @@ class DescriptorGeneratorCSV(CSVParser.CSVParser):
     # app-specific structure on the npz file.
     def retrieve_by_index(self, filename, index):
 
-        return self.npy_arrays[filename][index]
+        try:
+            desc = self.npy_arrays[filename][index]
+        except:
+            err_msg = "Cannot retrieve descriptor {} from {}".format(str(index), filename)
+            raise Exception(err_msg)
+
+        return desc
 
     def load_descriptor(self, filename, index):
 
