@@ -14,7 +14,12 @@ class ParallelLoader:
 
     def __init__(self, db, dry_run=False):
 
-        self.db = db
+        # db can me None in the case of Downloaders
+        # or other abstractions that want to use the parallel/batching
+        # structures without running queries
+        if db:
+            self.db = db.create_new_connection()
+
         self.dry_run = dry_run
 
         self.type = "element"
@@ -22,7 +27,6 @@ class ParallelLoader:
         # Default Values
         self.batchsize  = 1
         self.numthreads = 1
-        self.n_retries  = 1
 
         self.total_elements = 0
         self.times_arr = []
@@ -36,7 +40,7 @@ class ParallelLoader:
         q, blobs = self.generate_batch(data)
 
         if not self.dry_run:
-            r,b = db.query(q, blobs, n_retries=self.n_retries)
+            r,b = db.query(q, blobs)
             if not db.last_query_ok():
                 self.error_counter += 1
             query_time = db.get_last_query_time()
@@ -48,6 +52,7 @@ class ParallelLoader:
 
     def worker(self, thid, generator, start, end):
 
+        # A new connection will be created for each batch
         db = self.db.create_new_connection()
 
         if thid == 0 and self.stats:
@@ -69,7 +74,8 @@ class ParallelLoader:
                 data_for_query = [ generator[idx]
                                    for idx in range(batch_start, batch_end) ]
                 self.do_batch(db, data_for_query)
-            except:
+            except Exception as e:
+                print(e)
                 self.error_counter += 1
 
             if thid == 0 and self.stats:
@@ -118,19 +124,24 @@ class ParallelLoader:
         print("============ ApertureDB Loader Stats ============")
         print("Total time (s):", self.ingestion_time)
         print("Total queries executed:", total_queries_exec)
-        print("Avg Query time (s):", np.mean(times))
-        print("Query time std:", np.std (times))
-        print("Avg Query Throughput (q/s)):",
-                1 / np.mean(times) * self.numthreads)
 
-        msg = "(" + self.type + "/s):"
-        print("Overall insertion throughput", msg,
-                self.total_elements / self.ingestion_time)
+        if total_queries_exec == 0:
+            print("All queries failed!")
 
-        if self.error_counter > 0:
-            print("Total errors encountered:", self.error_counter)
-            inserted_elements -= self.error_counter * self.batchsize
-            print("Errors (%):", 100 * self.error_counter / total_queries_exec)
+        else:
+            print("Avg Query time (s):", np.mean(times))
+            print("Query time std:", np.std (times))
+            print("Avg Query Throughput (q/s)):",
+                    1 / np.mean(times) * self.numthreads)
 
-        print("Total inserted elements:", inserted_elements)
+            msg = "(" + self.type + "/s):"
+            print("Overall insertion throughput", msg,
+                    self.total_elements / self.ingestion_time)
+
+            if self.error_counter > 0:
+                print("Total errors encountered:", self.error_counter)
+                inserted_elements -= self.error_counter * self.batchsize
+                print("Errors (%):", 100 * self.error_counter / total_queries_exec)
+
+            print("Total inserted elements:", inserted_elements)
         print("=================================================")
